@@ -47,4 +47,18 @@
       }
     }
   }, force = TRUE)
+  shiny::registerInputHandler("sw.tree", function(data, ...) {
+    if (is.null(data) || length(data) < 1) {
+      NULL
+    } else {
+      return(unlist(data, use.names = FALSE))
+    }
+  }, force = TRUE)
+  shiny::registerInputHandler("sw.tree.all", function(data, ...) {
+    if (is.null(data)) {
+      NULL
+    } else {
+      data
+    }
+  }, force = TRUE)
 }
