@@ -17,7 +17,7 @@
 var radioGroupButtonsBinding = new Shiny.InputBinding();
 $.extend(radioGroupButtonsBinding, {
   find: function(scope) {
-    return $(scope).find(".radioGroupButtons");
+    return $(scope).find(".radio-group-buttons");
   },
   getId: function(el) {
     return el.id;
@@ -101,21 +101,33 @@ $.extend(radioGroupButtonsBinding, {
         .text(data.label);
 
     if (data.disabled) {
+      // bs3
       $el.find("button").attr("disabled", "disabled");
       $el.find("button").addClass("disabled");
+      // bs5
+      $el.find("label").addClass("disabled");
     } else {
+      // bs3
       $el.find("button").removeAttr("disabled");
       $el.find("button").removeClass("disabled");
+      // bs5
+      $el.find("label").removeClass("disabled");
     }
     if (data.hasOwnProperty("disabledChoices")) {
       for (var i = 0; i < data.disabledChoices.length; i++) {
-        $(
+        var toDisable = $(
           'input:radio[name="' +
             Shiny.$escape(el.id) +
             '"][value="' +
             Shiny.$escape(data.disabledChoices[i]) +
             '"]'
-        )
+        );
+        // bs5
+        toDisable
+          .next("label")
+          .addClass("disabled");
+        // bs3
+        toDisable
           .parent()
           .attr("disabled", "disabled")
           .addClass("disabled");
